@@ -592,6 +592,15 @@ impl<const K: usize, const V: usize> Lsm<K, V> {
                         break;
                     }
 
+                    if !buf[5 + U64_SZ..].iter().all(|e| *e == 0) {
+                        log::warn!(
+                            "expected all pad bytes after logged \
+                            batch manifests to be zero, but some \
+                            corruption was detected"
+                        );
+                        break;
+                    }
+
                     if batch_sz > usize::MAX as u64 {
                         return Err(io::Error::new(
                             io::ErrorKind::InvalidInput,
@@ -602,11 +611,15 @@ impl<const K: usize, const V: usize> Lsm<K, V> {
                     let wb_remaining = batch_sz as usize;
                     let wb_recovered = buf.len() as u64;
 
-                    write_batch = Some((
-                        Vec::with_capacity(batch_sz as usize),
-                        wb_remaining,
-                        wb_recovered,
-                    ));
+                    if wb_remaining > 0 {
+                        write_batch = Some((
+                            Vec::with_capacity(batch_sz as usize),
+                            wb_remaining,
+                            wb_recovered,
+                        ));
+                    } else {
+                        recovered += buf.len() as u64;
+                    }
 
                     continue;
                 }
@@ -634,6 +647,14 @@ impl<const K: usize, const V: usize> Lsm<K, V> {
                 break;
             }
 
+            if !buf[5 + K + V..].iter().all(|e| *e == 0) {
+                log::warn!(
+                    "expected all pad bytes for logged kv entries \
+                    to be zero, but some corruption was detected"
+                );
+                break;
+            }
+
             if let Some((mut wb, mut wb_remaining, mut wb_recovered)) = write_batch.take() {
                 wb.push((k, v));
                 wb_remaining = wb_remaining.checked_sub(1).unwrap();
